@@ -1,12 +1,12 @@
 package Test::Perinci::Tx::Manager;
 
-our $DATE = '2016-06-10'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use File::Remove qw(remove);
 use Perinci::Access::Schemeless;
@@ -160,7 +160,7 @@ sub test_tx_action {
                         return if $args{which} eq 'rollback';
                         $ja++ if $args{which} eq 'action';
                         if ($ja == $i && $nl == ($has_do_actions ? 2:1)) {
-                            for ("CRASH DURING ACTION") {$log->trace($_);die $_}
+                            for ("CRASH DURING ACTION") {log_trace($_);die $_}
                        }
                     };
                     eval {
@@ -205,12 +205,12 @@ sub test_tx_action {
                             # we need to trigger the rollback first, after last
                             # action
                             return unless ++$ja >= $num_actions;
-                            for ("CRASH DURING ACTION") {$log->trace($_);die $_}
+                            for ("CRASH DURING ACTION") {log_trace($_);die $_}
                         }
                         $jrb++ if $args{which} eq 'rollback';
                         if ($jrb == $i) {
                             for("CRASH DURING ROLLBACK"){
-                                $crashed++; $log->trace($_); die $_;
+                                $crashed++; log_trace($_); die $_;
                             }
                         }
                     };
@@ -292,7 +292,7 @@ sub test_tx_action {
                         return unless $args{which} eq 'undo';
                         if (++$ju == $i) {
                             for ("CRASH DURING UNDO ACTION") {
-                                $log->trace($_);die $_;
+                                log_trace($_);die $_;
                             }
                         }
                     };
@@ -346,13 +346,13 @@ sub test_tx_action {
                             # first we trigger a rollback at the last step
                             if (++$ju == $num_undo_actions) {
                                 for ("CRASH DURING UNDO ACTION") {
-                                    $log->trace($_);die $_;
+                                    log_trace($_);die $_;
                                 }
                             }
                         } elsif ($args{which} eq 'rollback') {
                             if (++$jrb == $i) {
                                 for ("CRASH DURING ROLLBACK") {
-                                    $crashed++; $log->trace($_);die $_;
+                                    $crashed++; log_trace($_);die $_;
                                 }
                             }
                         }
@@ -410,7 +410,7 @@ sub test_tx_action {
                         return unless $args{which} eq 'redo';
                         if (++$jrd == $i) {
                             for ("CRASH DURING REDO ACTION") {
-                                $crashed++; $log->trace($_); die $_;
+                                $crashed++; log_trace($_); die $_;
                             }
                         }
                     };
@@ -466,13 +466,13 @@ sub test_tx_action {
                             # first we trigger a rollback at the last step
                             if (++$jrd == $num_actions) {
                                 for ("CRASH DURING REDO ACTION") {
-                                    $log->trace($_);die $_;
+                                    log_trace($_);die $_;
                                 }
                             }
                         } elsif ($args{which} eq 'rollback') {
                             if (++$jrb == $i) {
                                 for ("CRASH DURING ROLLBACK") {
-                                    $crashed++; $log->trace($_); die $_;
+                                    $crashed++; log_trace($_); die $_;
                                 }
                             }
                         }
@@ -522,7 +522,7 @@ Test::Perinci::Tx::Manager - Transaction tests
 
 =head1 VERSION
 
-This document describes version 0.56 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2016-06-10.
+This document describes version 0.57 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
@@ -594,7 +594,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
